==> bbwa-0.0.5.tar.gz: bbwa-0.0.5/help.php <==
<?php
//
// BBWA
// help.php
// إץڡɽ
// Teppei KAKU <teppei@sat.co.jp>
//

include("variables.php");
?>


<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<title>BBWA</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-jp">


<?php
print("<link rel=\"stylesheet\" type=\"text/css\" href=\"Themes/${theme}.css\">");
?>


</head>
<body class="right">
<table border="0" width="100%" align="center">
<tr><td class="right">
<h4>Ȥ</h4>
<ul>
<li>ڡΥܥǳƼԤޤ<br>
<img src="Icons/icon_first.png" align="absmiddle">
ХƬΥڡذư<br>
<img src="Icons/icon_left.png" align="absmiddle">
ҤȤΥڡذư<br>
<img src="Icons/icon_right.png" align="absmiddle">
Υڡذư<br>
<img src="Icons/icon_last.png" align="absmiddle">
ǸΥڡذư<br>
<img src="Icons/icon_home.png" align="absmiddle">
 Web ȤΥۡڡذư<br>
<img src="Icons/icon_new.png" align="absmiddle">
<br>
<img src="Icons/icon_help.png" align="absmiddle">
إ(Υڡ)ɽ<br>
<img src="Icons/icon_thumb.png" align="absmiddle">
̥ɥɽ
<br><br>
<li>ڡܥåǡ¤ؤˡѹ뤳ȤǤޤ
ǥեȤϿȤĤɽ褦ˤʤäƤޤ
¾˲Ͽ줿򿷤ΡŤν¤٤뤳ȤǤޤ
<br><br>
<li>ڡ¦ν̾򥯥åȡ¦ˤβξܺپ
ɽޤܺپβȥޤϥڡ¦ɽ
줿̾򥯥åȡβ̥ɥǼʪɽޤ
<br><br>
<li>ʪɽΥɥϡɽʬ⤷ϥɥΡx٥ܥ
򥯥åĤ뤳ȤǤޤ<br><br>
<li>줾βˤϡȤĤ뤳ȤǤޤƲξܺپβ
ˤϥե̾ӥȤϤơ٤򲡤Ƥ
<br><br>
<li>ɽΥɥ
<img src="Icons/icon_fresh.png" align="absmiddle">
ĤƤϡ24ְ˿Ƥ⤷ϥȽ񤭹ߤä
Ǥ
<br><br>
<li>ӽݤˤϡܺɽڡΡإѥɡ
βƤȤΥѥɤޤϴԥѥɤϤơغ
ޤϡؽ٥ܥ򲡤Ƥ
</ul>
<br><h4>ջ</h4>
<ul>
<li>Microsoft Internet Explorer 5/6  Mozilla 1.0 ưǧƤޤ
ʳΥ֥饦ư뤫ɤǤޤJavaScript
 Cookie ͭˤƻѤƤ<br><br>
<li>ߥåץɲǽʥեϡJPEGPNGGIF եޥåȤβ
եΤߤǤ<br><br>
<li>GIF եΥåץɤϡɬפʾ(˥᡼ GIF ʤ)
ƶ򤱤ƤۤȤɾ JPEG ޤ PNG եޥåȤ
ǤޤΤǤѤƤ<br><br>
<li>Cookie ѡ٤Υåä(ǥե)ǲ䥳ȤϿ̾᡼륢ɥ쥹¸ޤ¿ѤѥƤȤϡCookie ѡ٤ΥåϳƤ⤷ޤ
</ul>
<br><br>
</td></tr>
</body>
</html>

==> bbwa-0.0.6.tar.gz: bbwa-0.0.6/help.php <==
<?php
//
// BBWA
// help.php
// إץڡɽ
// Teppei KAKU <teppei@sat.co.jp>
//

include("variables.php");
?>


<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<title>BBWA</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-jp">


<?php
print("<link rel=\"stylesheet\" type=\"text/css\" href=\"Themes/${theme}.css\">");
?>


</head>
<body class="right">
<table border="0" width="100%" align="center">
<tr><td class="right">
<h4>Ȥ</h4>
<ul>
<li>ڡΥܥǳƼԤޤ<br>
<img src="Icons/icon_first.png" align="absmiddle">
ХƬΥڡذư<br>
<img src="Icons/icon_left.png" align="absmiddle">
ҤȤΥڡذư<br>
<img src="Icons/icon_right.png" align="absmiddle">
Υڡذư<br>
<img src="Icons/icon_last.png" align="absmiddle">
ǸΥڡذư<br>
<img src="Icons/icon_home.png" align="absmiddle">
 Web ȤΥۡڡذư<br>
<img src="Icons/icon_new.png" align="absmiddle">
<br>
<img src="Icons/icon_help.png" align="absmiddle">
إ(Υڡ)ɽ<br>
<img src="Icons/icon_thumb.png" align="absmiddle">
̥ɥɽ
<br><br>
<li>ڡܥåǡ¤ؤˡѹ뤳ȤǤޤ
ǥեȤϿȤĤɽ褦ˤʤäƤޤ
¾˲Ͽ줿򿷤ΡŤν¤٤뤳ȤǤޤ
<br><br>
<li>ڡ¦ν̾򥯥åȡ¦ˤβξܺپ
ɽޤܺپβȥޤϥڡ¦ɽ
줿̾򥯥åȡβ̥ɥǼʪɽޤ
<br><br>
<li>줾βˤϡȤĤ뤳ȤǤޤƲξܺپβ
ˤϥե̾ӥȤϤơ٤򲡤Ƥ
ޤ줾βФơGood١Bad٤ɼ뤳ȤǤޤɼ
Good٤γ礬إ٤Ȥɽޤ
<br><br>
<li>ɽΥɥ
<img src="Icons/icon_fresh.png" align="absmiddle">
ĤƤϡ24ְ˿Ƥ⤷ϥȽ񤭹ߤä
Ǥ
<br><br>
<li>ӽݤˤϡܺɽڡΡإѥɡ
βƤȤΥѥɤޤϴԥѥɤϤơغ
ޤϡؽ٥ܥ򲡤Ƥ
</ul>
<br><h4>ջ</h4>
<ul>
<li>Microsoft Internet Explorer 5/6  Mozilla 1.0 ưǧƤޤ
ʳΥ֥饦ư뤫ɤǤޤJavaScript
 Cookie ͭˤƻѤƤ<br><br>
<li>ߥåץɲǽʥեϡJPEGPNGGIF եޥåȤβ
եΤߤǤ<br><br>
<li>GIF եΥåץɤϡɬפʾ(˥᡼ GIF ʤ)
ƶ򤱤ƤۤȤɾ JPEG ޤ PNG եޥåȤ
ǤޤΤǤѤƤ<br><br>
<li>Cookie ѡ٤Υåä(ǥե)ǲ䥳ȤϿ
̾᡼륢ɥ쥹¸ޤ¿Ѥѥ
ƤȤϡCookie ѡ٤ΥåϳƤ⤷ޤ
</ul>
<br><br>
</td></tr>
</body>
</html>
